From 4f35a00a3522b6bbb8ab5767b799a33831907533 Mon Sep 17 00:00:00 2001
From: vogelor <vogelor@ispconfig3>
Date: Tue, 04 May 2010 13:09:37 -0400
Subject: [PATCH] Added new theme. You now can change between 64px size icons, 32px size icons (the default-value) and no icons

---
 interface/web/admin/language_export.php |    7 ++-----
 1 files changed, 2 insertions(+), 5 deletions(-)

diff --git a/interface/web/admin/language_export.php b/interface/web/admin/language_export.php
index c2c6343..d252073 100644
--- a/interface/web/admin/language_export.php
+++ b/interface/web/admin/language_export.php
@@ -30,11 +30,8 @@
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
 
-// Checking permissions for the module
-if(!stristr($_SESSION['s']['user']['modules'],'admin')) {
-	header('Location: ../index.php');
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('admin');
 
 //* This is only allowed for administrators
 if(!$app->auth->is_admin()) die('only allowed for administrators.');

--
Gitblit v1.9.1